WinVideoPlayerValue class

Annotations

Constructors

WinVideoPlayerValue({int textureId = -1, Duration duration = Duration.zero, Size size = Size.zero, Duration position = Duration.zero, bool isInitialized = false, bool isPlaying = false, bool isLooping = false, bool isBuffering = false, bool isCompleted = false, double volume = 1.0, double playbackSpeed = 1.0, String? errorDescription})
const

Properties

aspectRatio double
no setter
duration Duration
final
errorDescription String?
final
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isBuffering bool
final
isCompleted bool
final
isInitialized bool
final
isLooping bool
final
isPlaying bool
final
playbackSpeed double
final
position Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
textureId int
final
volume double
final

Methods

copyWith({int? textureId, Duration? duration, bool? isBuffering, bool? isInitialized, bool? isLooping, bool? isPlaying, bool? isCompleted, double? playbackSpeed, Duration? position, Size? size, double? volume, String? errorDescription}) WinVideoPlayerValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited