MethodChannelVideoPlayerWin class

An implementation of VideoPlayerWinPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
playerMap → Map<int, WeakReference<WinVideoPlayerController>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose(int textureId) → Future<void>
override
getCurrentPosition(int textureId) → Future<int>
override
getDuration(int textureId) → Future<int>
override
getPlayerByTextureId(int textureId) → WinVideoPlayerController?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openVideo(WinVideoPlayerController player, int textureId, String path, Map<String, String> httpHeaders) → Future<WinVideoPlayerValue?>
override
pause(int textureId) → Future<void>
override
play(int textureId) → Future<void>
override
registerPlayer(int textureId, WinVideoPlayerController player) → void
inherited
seekTo(int textureId, int ms) → Future<void>
override
setPlaybackSpeed(int textureId, double speed) → Future<void>
override
setVolume(int textureId, double volume) → Future<void>
override
toString() → String
A string representation of this object.
inherited
unregisterPlayer(int textureId) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited