VideoPlayerWinPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • VideoPlayerWinPlatform
Implementers

Constructors

VideoPlayerWinPlatform()
Constructs a VideoPlayerWinPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose(int textureId) → Future<void>
getCurrentPosition(int textureId) → Future<int>
getDuration(int textureId) → Future<int?>
getPlayerByTextureId(int textureId) → WinVideoPlayerController?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openVideo(WinVideoPlayerController player, int textureId, String path, Map<String, String> httpHeaders) → Future<WinVideoPlayerValue?>
pause(int textureId) → Future<void>
play(int textureId) → Future<void>
registerPlayer(int textureId, WinVideoPlayerController player) → void
seekTo(int textureId, int ms) → Future<void>
setPlaybackSpeed(int textureId, double speed) → Future<void>
setVolume(int textureId, double volume) → Future<void>
toString() → String
A string representation of this object.
inherited
unregisterPlayer(int textureId) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ VideoPlayerWinPlatform
The default instance of VideoPlayerWinPlatform to use.
getter/setter pair