getVideoTracks method

Future<List<VideoTrack>> getVideoTracks(
  1. int playerId
)
inherited

Gets the available video tracks (quality variants) for the video.

Returns a list of VideoTrack objects representing the available video quality variants. For HLS/DASH streams, this returns the different quality levels available. For non-adaptive videos, platform implementations may return one or more tracks, or an empty list, depending on the media and the metadata available.

Implementation

Future<List<VideoTrack>> getVideoTracks(int playerId) {
  throw UnimplementedError('getVideoTracks() has not been implemented.');
}