isVideoTrackSupportAvailable method

bool isVideoTrackSupportAvailable()
inherited

Returns whether video track selection is supported on this platform.

This method allows developers to query at runtime whether the current platform supports video track (quality) selection functionality. This is useful for platforms like web where video track selection may not be available.

Returns true if getVideoTracks and selectVideoTrack are supported, false otherwise.

The default implementation returns false. Platform implementations should override this to return true if they support video track selection.

Implementation

bool isVideoTrackSupportAvailable() {
  return false;
}