setPreventsDisplaySleepDuringVideoPlayback method

Future<void> setPreventsDisplaySleepDuringVideoPlayback(
  1. int playerId,
  2. bool preventsDisplaySleepDuringVideoPlayback
)
inherited

Sets whether the screen is prevented from sleeping during video playback.

The default implementation is a no-op, so platforms that do not support controlling display sleep will silently use their default behavior.

Implementation

Future<void> setPreventsDisplaySleepDuringVideoPlayback(
  int playerId,
  bool preventsDisplaySleepDuringVideoPlayback,
) async {}