WinVideoPlayerController class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
WinVideoPlayerValue> - WinVideoPlayerController
Constructors
- WinVideoPlayerController.asset(String dataSource, {String? package, bool isPluginMode = false})
- WinVideoPlayerController.contentUri(Uri contentUri)
- WinVideoPlayerController.file(File file, {bool isPluginMode = false})
-
WinVideoPlayerController.network(String dataSource, {bool isPluginMode = false, Map<
String, String> httpHeaders = const {}}) -
WinVideoPlayerController.networkUrl(Uri url, {bool isPluginMode = false, Map<
String, String> httpHeaders = const {}})
Properties
- dataSource → String
-
final
- dataSourceType ↔ WinDataSourceType
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
httpHeaders
→ Map<
String, String> -
final
-
position
→ Future<
Duration?> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textureId_ ↔ int
-
getter/setter pair
- value ↔ WinVideoPlayerValue
-
The current value stored in this notifier.
getter/setter pairinherited
-
videoEventStream
→ Stream<
VideoEvent> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → Future< void> -
Discards any resources used by the object.
override
-
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onPlaybackEvent_(
int state) → void -
pause(
) → Future< void> -
play(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
seekTo(
Duration time) → Future< void> -
setLooping(
bool looping) → Future< void> -
setPlaybackSpeed(
double speed) → Future< void> -
setVolume(
double volume) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAssetPath(
String dataSource) → String