WindowsVideoPlayer class

Inheritance
  • Object
  • PlatformInterface
  • VideoPlayerPlatform
  • WindowsVideoPlayer

Constructors

WindowsVideoPlayer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mControllerMap → Map<int, WinVideoPlayerController>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildView(int textureId) → Widget
Returns a widget displaying the video with a given textureID.
override
buildViewWithOptions(VideoViewOptions options) → Widget
Returns a widget displaying the video based on given options.
inherited
create(DataSource dataSource) → Future<int?>
Creates an instance of a video player and returns its textureId.
override
createWithOptions(VideoCreationOptions options) → Future<int?>
Creates an instance of a video player based on creation options and returns its playerId.
inherited
dispose(int textureId) → Future<void>
Clears one video.
override
getAudioTracks(int playerId) → Future<List<VideoAudioTrack>>
Gets the available audio tracks for the video.
inherited
getPosition(int textureId) → Future<Duration>
Gets the video position as Duration from the start.
override
getVideoTracks(int playerId) → Future<List<VideoTrack>>
Gets the available video tracks (quality variants) for the video.
inherited
init() → Future<void>
Initializes the platform interface and disposes all existing players.
override
isAudioTrackSupportAvailable() → bool
Returns whether audio track selection is supported on this platform.
inherited
isVideoTrackSupportAvailable() → bool
Returns whether video track selection is supported on this platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int textureId) → Future<void>
Stops the video playback.
override
play(int textureId) → Future<void>
Starts the video playback.
override
seekTo(int textureId, Duration position) → Future<void>
Sets the video position to a Duration from the start.
override
selectAudioTrack(int playerId, String trackId) → Future<void>
Selects which audio track is chosen for playback from its trackId
inherited
selectVideoTrack(int playerId, VideoTrack? track) → Future<void>
Selects which video track (quality variant) is chosen for playback.
inherited
setAllowBackgroundPlayback(bool allowBackgroundPlayback) → Future<void>
Sets whether the video should continue to play in the background.
inherited
setLooping(int textureId, bool looping) → Future<void>
Sets the looping attribute of the video.
override
setMixWithOthers(bool mixWithOthers) → Future<void>
Sets the audio mode to mix with other sources
override
setPlaybackSpeed(int textureId, double speed) → Future<void>
Sets the playback speed to a speed value indicating the playback rate.
override
setPreventsDisplaySleepDuringVideoPlayback(int playerId, bool preventsDisplaySleepDuringVideoPlayback) → Future<void>
Sets whether the screen is prevented from sleeping during video playback.
inherited
setVolume(int textureId, double volume) → Future<void>
Sets the volume to a range between 0.0 and 1.0.
override
setWebOptions(int playerId, VideoPlayerWebOptions options) → Future<void>
Sets additional options on web.
inherited
toString() → String
A string representation of this object.
inherited
videoEventsFor(int textureId) → Stream<VideoEvent>
Returns a Stream of VideoEventTypes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith() → void